==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkOctreePointLocatorNode.java <==
// java wrapper for vtkOctreePointLocatorNode object
//

package vtk;
import vtk.*;

public class vtkOctreePointLocatorNode extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPoints_2(int id0);
  public void SetNumberOfPoints(int id0)
    { SetNumberOfPoints_2(id0); }

  private native int GetNumberOfPoints_3();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_3(); }

  private native void SetBounds_4(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_4(id0,id1,id2,id3,id4,id5); }

  private native void SetBounds_5(double id0[]);
  public void SetBounds(double id0[])
    { SetBounds_5(id0); }

  private native void SetDataBounds_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetDataBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetDataBounds_6(id0,id1,id2,id3,id4,id5); }

  private native void SetMinBounds_7(double id0[]);
  public void SetMinBounds(double id0[])
    { SetMinBounds_7(id0); }

  private native void SetMaxBounds_8(double id0[]);
  public void SetMaxBounds(double id0[])
    { SetMaxBounds_8(id0); }

  private native void SetMinDataBounds_9(double id0[]);
  public void SetMinDataBounds(double id0[])
    { SetMinDataBounds_9(id0); }

  private native void SetMaxDataBounds_10(double id0[]);
  public void SetMaxDataBounds(double id0[])
    { SetMaxDataBounds_10(id0); }

  private native int GetID_11();
  public int GetID()
    { return GetID_11(); }

  private native int GetMinID_12();
  public int GetMinID()
    { return GetMinID_12(); }

  private native void CreateChildNodes_13();
  public void CreateChildNodes()
    { CreateChildNodes_13(); }

  private native void DeleteChildNodes_14();
  public void DeleteChildNodes()
    { DeleteChildNodes_14(); }

  private native long GetChild_15(int id0);
  public vtkOctreePointLocatorNode GetChild(int id0) {
    long temp = GetChild_15(id0);

    if (temp == 0) return null;
    return (vtkOctreePointLocatorNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int IntersectsRegion_16(vtkPlanesIntersection id0,int id1);
  public int IntersectsRegion(vtkPlanesIntersection id0,int id1)
    { return IntersectsRegion_16(id0,id1); }

  private native int ContainsPoint_17(double id0,double id1,double id2,int id3);
  public int ContainsPoint(double id0,double id1,double id2,int id3)
    { return ContainsPoint_17(id0,id1,id2,id3); }

  private native double GetDistance2ToBoundary_18(double id0,double id1,double id2,vtkOctreePointLocatorNode id3,int id4);
  public double GetDistance2ToBoundary(double id0,double id1,double id2,vtkOctreePointLocatorNode id3,int id4)
    { return GetDistance2ToBoundary_18(id0,id1,id2,id3,id4); }

  private native double GetDistance2ToInnerBoundary_19(double id0,double id1,double id2,vtkOctreePointLocatorNode id3);
  public double GetDistance2ToInnerBoundary(double id0,double id1,double id2,vtkOctreePointLocatorNode id3)
    { return GetDistance2ToInnerBoundary_19(id0,id1,id2,id3); }

  public vtkOctreePointLocatorNode() { super(); }

  public vtkOctreePointLocatorNode(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv6h.pkg.tar.xz: vtk/vtkOctreePointLocatorNode.java <==
// java wrapper for vtkOctreePointLocatorNode object
//

package vtk;
import vtk.*;

public class vtkOctreePointLocatorNode extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPoints_2(int id0);
  public void SetNumberOfPoints(int id0)
    { SetNumberOfPoints_2(id0); }

  private native int GetNumberOfPoints_3();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_3(); }

  private native void SetBounds_4(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_4(id0,id1,id2,id3,id4,id5); }

  private native void SetBounds_5(double id0[]);
  public void SetBounds(double id0[])
    { SetBounds_5(id0); }

  private native void SetDataBounds_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetDataBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetDataBounds_6(id0,id1,id2,id3,id4,id5); }

  private native void SetMinBounds_7(double id0[]);
  public void SetMinBounds(double id0[])
    { SetMinBounds_7(id0); }

  private native void SetMaxBounds_8(double id0[]);
  public void SetMaxBounds(double id0[])
    { SetMaxBounds_8(id0); }

  private native void SetMinDataBounds_9(double id0[]);
  public void SetMinDataBounds(double id0[])
    { SetMinDataBounds_9(id0); }

  private native void SetMaxDataBounds_10(double id0[]);
  public void SetMaxDataBounds(double id0[])
    { SetMaxDataBounds_10(id0); }

  private native int GetID_11();
  public int GetID()
    { return GetID_11(); }

  private native int GetMinID_12();
  public int GetMinID()
    { return GetMinID_12(); }

  private native void CreateChildNodes_13();
  public void CreateChildNodes()
    { CreateChildNodes_13(); }

  private native void DeleteChildNodes_14();
  public void DeleteChildNodes()
    { DeleteChildNodes_14(); }

  private native long GetChild_15(int id0);
  public vtkOctreePointLocatorNode GetChild(int id0) {
    long temp = GetChild_15(id0);

    if (temp == 0) return null;
    return (vtkOctreePointLocatorNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IntersectsRegion_16(vtkPlanesIntersection id0,int id1);
  public int IntersectsRegion(vtkPlanesIntersection id0,int id1)
    { return IntersectsRegion_16(id0,id1); }

  private native int ContainsPoint_17(double id0,double id1,double id2,int id3);
  public int ContainsPoint(double id0,double id1,double id2,int id3)
    { return ContainsPoint_17(id0,id1,id2,id3); }

  private native double GetDistance2ToBoundary_18(double id0,double id1,double id2,vtkOctreePointLocatorNode id3,int id4);
  public double GetDistance2ToBoundary(double id0,double id1,double id2,vtkOctreePointLocatorNode id3,int id4)
    { return GetDistance2ToBoundary_18(id0,id1,id2,id3,id4); }

  private native double GetDistance2ToInnerBoundary_19(double id0,double id1,double id2,vtkOctreePointLocatorNode id3);
  public double GetDistance2ToInnerBoundary(double id0,double id1,double id2,vtkOctreePointLocatorNode id3)
    { return GetDistance2ToInnerBoundary_19(id0,id1,id2,id3); }

  public vtkOctreePointLocatorNode() { super(); }

  public vtkOctreePointLocatorNode(long id) { super(id); }
  public native long   VTKInit();

}
